# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.invoices_resource import InvoicesResource

class TestInvoicesResource(unittest.TestCase):
    """InvoicesResource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvoicesResource:
        """Test InvoicesResource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvoicesResource`
        """
        model = InvoicesResource()
        if include_optional:
            return InvoicesResource(
                id = '37',
                type = 'invoices',
                attributes = jubladb_api.models.invoices.invoices(
                    title = '', 
                    description = '', 
                    state = '', 
                    group_id = 56, 
                    recipient_id = 56, 
                    due_at = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    issued_at = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    recipient_email = '', 
                    payment_information = '', 
                    payment_purpose = '', 
                    hide_total = True, ),
                relationships = jubladb_api.models.invoices_relationships.invoices_relationships(
                    group = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(
                        links = { }, 
                        data = jubladb_api.models.jsonapi_linkage.jsonapi_linkage(
                            type = 'additional_emails', 
                            meta = { }, 
                            id = '44', ), 
                        meta = { }, ), 
                    recipient = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(), 
                    invoice_items = jubladb_api.models.courses_relationships_dates.courses_relationships_dates(), ),
                links = {
                    'key' : null
                    }
            )
        else:
            return InvoicesResource(
        )
        """

    def testInvoicesResource(self):
        """Test InvoicesResource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
