# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.api.event_kind_categories_api import EventKindCategoriesApi


class TestEventKindCategoriesApi(unittest.TestCase):
    """EventKindCategoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventKindCategoriesApi()

    def tearDown(self) -> None:
        pass

    def test_get_event_kind_category(self) -> None:
        """Test case for get_event_kind_category

        Fetch Event kind category
        """
        pass

    def test_list_event_kind_categories(self) -> None:
        """Test case for list_event_kind_categories

        List Event kind categories
        """
        pass


if __name__ == '__main__':
    unittest.main()
