# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.event_kinds_relationships import EventKindsRelationships

class TestEventKindsRelationships(unittest.TestCase):
    """EventKindsRelationships unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EventKindsRelationships:
        """Test EventKindsRelationships
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EventKindsRelationships`
        """
        model = EventKindsRelationships()
        if include_optional:
            return EventKindsRelationships(
                kind_category = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(
                    links = { }, 
                    data = jubladb_api.models.jsonapi_linkage.jsonapi_linkage(
                        type = 'additional_emails', 
                        meta = { }, 
                        id = '44', ), 
                    meta = { }, )
            )
        else:
            return EventKindsRelationships(
        )
        """

    def testEventKindsRelationships(self):
        """Test EventKindsRelationships"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
