# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.jsonapi_linkage import JsonapiLinkage

class TestJsonapiLinkage(unittest.TestCase):
    """JsonapiLinkage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JsonapiLinkage:
        """Test JsonapiLinkage
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JsonapiLinkage`
        """
        model = JsonapiLinkage()
        if include_optional:
            return JsonapiLinkage(
                type = 'additional_emails',
                meta = { },
                id = '44'
            )
        else:
            return JsonapiLinkage(
                type = 'additional_emails',
                id = '44',
        )
        """

    def testJsonapiLinkage(self):
        """Test JsonapiLinkage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
