# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.people import People

class TestPeople(unittest.TestCase):
    """People unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> People:
        """Test People
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `People`
        """
        model = People()
        if include_optional:
            return People(
                first_name = '',
                last_name = '',
                nickname = '',
                company_name = '',
                company = True,
                email = '',
                address = '',
                zip_code = '',
                town = '',
                country = '',
                primary_group_id = 56,
                gender = '',
                birthday = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                language = ''
            )
        else:
            return People(
        )
        """

    def testPeople(self):
        """Test People"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
