# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class EventsReadableAttribute(str, Enum):
    """
    Event readable attributes
    """

    """
    allowed enum values
    """
    ID = 'id'
    GROUP_IDS = 'group_ids'
    TYPE = 'type'
    KIND_ID = 'kind_id'
    NAME = 'name'
    DESCRIPTION = 'description'
    APPLICATION_CONDITIONS = 'application_conditions'
    MOTTO = 'motto'
    COST = 'cost'
    LOCATION = 'location'
    APPLICATION_OPENING_AT = 'application_opening_at'
    APPLICATION_CLOSING_AT = 'application_closing_at'
    APPLICATION_CONTACT_ID = 'application_contact_id'
    EXTERNAL_APPLICATION_LINK = 'external_application_link'
    MAXIMUM_PARTICIPANTS = 'maximum_participants'
    CREATED_AT = 'created_at'
    UPDATED_AT = 'updated_at'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of EventsReadableAttribute from a JSON string"""
        return cls(json.loads(json_str))


