# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.roles_readable_attribute import RolesReadableAttribute

class TestRolesReadableAttribute(unittest.TestCase):
    """RolesReadableAttribute unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRolesReadableAttribute(self):
        """Test RolesReadableAttribute"""
        # inst = RolesReadableAttribute()

if __name__ == '__main__':
    unittest.main()
