# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class InvoiceItemsReadableAttribute(str, Enum):
    """
    Invoice item readable attributes
    """

    """
    allowed enum values
    """
    ID = 'id'
    INVOICE_ID = 'invoice_id'
    NAME = 'name'
    DESCRIPTION = 'description'
    UNIT_COST = 'unit_cost'
    VAT_RATE = 'vat_rate'
    COST = 'cost'
    COUNT = 'count'
    COST_CENTER = 'cost_center'
    ACCOUNT = 'account'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of InvoiceItemsReadableAttribute from a JSON string"""
        return cls(json.loads(json_str))


