# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from jubladb_api.models.courses_relationships_contact import CoursesRelationshipsContact
from jubladb_api.models.courses_relationships_dates import CoursesRelationshipsDates
from typing import Optional, Set
from typing_extensions import Self

class PeopleRelationships(BaseModel):
    """
    PeopleRelationships
    """ # noqa: E501
    primary_group: Optional[CoursesRelationshipsContact] = None
    layer_group: Optional[CoursesRelationshipsContact] = None
    roles: Optional[CoursesRelationshipsDates] = None
    phone_numbers: Optional[CoursesRelationshipsDates] = None
    social_accounts: Optional[CoursesRelationshipsDates] = None
    additional_emails: Optional[CoursesRelationshipsDates] = None
    __properties: ClassVar[List[str]] = ["primary_group", "layer_group", "roles", "phone_numbers", "social_accounts", "additional_emails"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PeopleRelationships from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of primary_group
        if self.primary_group:
            _dict['primary_group'] = self.primary_group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of layer_group
        if self.layer_group:
            _dict['layer_group'] = self.layer_group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of roles
        if self.roles:
            _dict['roles'] = self.roles.to_dict()
        # override the default output from pydantic by calling `to_dict()` of phone_numbers
        if self.phone_numbers:
            _dict['phone_numbers'] = self.phone_numbers.to_dict()
        # override the default output from pydantic by calling `to_dict()` of social_accounts
        if self.social_accounts:
            _dict['social_accounts'] = self.social_accounts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of additional_emails
        if self.additional_emails:
            _dict['additional_emails'] = self.additional_emails.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PeopleRelationships from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "primary_group": CoursesRelationshipsContact.from_dict(obj["primary_group"]) if obj.get("primary_group") is not None else None,
            "layer_group": CoursesRelationshipsContact.from_dict(obj["layer_group"]) if obj.get("layer_group") is not None else None,
            "roles": CoursesRelationshipsDates.from_dict(obj["roles"]) if obj.get("roles") is not None else None,
            "phone_numbers": CoursesRelationshipsDates.from_dict(obj["phone_numbers"]) if obj.get("phone_numbers") is not None else None,
            "social_accounts": CoursesRelationshipsDates.from_dict(obj["social_accounts"]) if obj.get("social_accounts") is not None else None,
            "additional_emails": CoursesRelationshipsDates.from_dict(obj["additional_emails"]) if obj.get("additional_emails") is not None else None
        })
        return _obj


