# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class InvoicesReadableAttribute(str, Enum):
    """
    Invoice readable attributes
    """

    """
    allowed enum values
    """
    ID = 'id'
    TITLE = 'title'
    DESCRIPTION = 'description'
    STATE = 'state'
    GROUP_ID = 'group_id'
    RECIPIENT_ID = 'recipient_id'
    DUE_AT = 'due_at'
    ISSUED_AT = 'issued_at'
    RECIPIENT_EMAIL = 'recipient_email'
    PAYMENT_INFORMATION = 'payment_information'
    PAYMENT_PURPOSE = 'payment_purpose'
    HIDE_TOTAL = 'hide_total'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of InvoicesReadableAttribute from a JSON string"""
        return cls(json.loads(json_str))


