# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class GroupsReadableAttribute(str, Enum):
    """
    Group readable attributes
    """

    """
    allowed enum values
    """
    ID = 'id'
    NAME = 'name'
    SHORT_NAME = 'short_name'
    DISPLAY_NAME = 'display_name'
    DESCRIPTION = 'description'
    LAYER = 'layer'
    PARENT_ID = 'parent_id'
    LAYER_GROUP_ID = 'layer_group_id'
    TYPE = 'type'
    EMAIL = 'email'
    ADDRESS = 'address'
    ZIP_CODE = 'zip_code'
    TOWN = 'town'
    COUNTRY = 'country'
    REQUIRE_PERSON_ADD_REQUESTS = 'require_person_add_requests'
    SELF_REGISTRATION_URL = 'self_registration_url'
    ARCHIVED_AT = 'archived_at'
    CREATED_AT = 'created_at'
    UPDATED_AT = 'updated_at'
    DELETED_AT = 'deleted_at'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of GroupsReadableAttribute from a JSON string"""
        return cls(json.loads(json_str))


