# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.api.roles_api import RolesApi


class TestRolesApi(unittest.TestCase):
    """RolesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RolesApi()

    def tearDown(self) -> None:
        pass

    def test_create_role(self) -> None:
        """Test case for create_role

        Create Role
        """
        pass

    def test_delete_role(self) -> None:
        """Test case for delete_role

        Destroy Role
        """
        pass

    def test_get_role(self) -> None:
        """Test case for get_role

        Fetch Role
        """
        pass

    def test_list_roles(self) -> None:
        """Test case for list_roles

        List Roles
        """
        pass

    def test_update_role(self) -> None:
        """Test case for update_role

        Update Role
        """
        pass


if __name__ == '__main__':
    unittest.main()
