# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.jsonapi_failure import JsonapiFailure

class TestJsonapiFailure(unittest.TestCase):
    """JsonapiFailure unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JsonapiFailure:
        """Test JsonapiFailure
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JsonapiFailure`
        """
        model = JsonapiFailure()
        if include_optional:
            return JsonapiFailure(
                errors = [
                    jubladb_api.models.jsonapi_error.jsonapi_error(
                        links = {
                            'key' : null
                            }, 
                        status = '', 
                        code = '', 
                        title = '', 
                        detail = '', 
                        source = jubladb_api.models.jsonapi_error_source.jsonapi_error_source(
                            pointer = '', 
                            parameter = '', ), 
                        meta = { }, )
                    ],
                meta = { },
                jsonapi = jubladb_api.models.jsonapi_jsonapi.jsonapi_jsonapi(
                    version = '1.0', 
                    meta = { }, ),
                links = {
                    'key' : null
                    }
            )
        else:
            return JsonapiFailure(
                errors = [
                    jubladb_api.models.jsonapi_error.jsonapi_error(
                        links = {
                            'key' : null
                            }, 
                        status = '', 
                        code = '', 
                        title = '', 
                        detail = '', 
                        source = jubladb_api.models.jsonapi_error_source.jsonapi_error_source(
                            pointer = '', 
                            parameter = '', ), 
                        meta = { }, )
                    ],
        )
        """

    def testJsonapiFailure(self):
        """Test JsonapiFailure"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
