# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.invoice_items_collection import InvoiceItemsCollection

class TestInvoiceItemsCollection(unittest.TestCase):
    """InvoiceItemsCollection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvoiceItemsCollection:
        """Test InvoiceItemsCollection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvoiceItemsCollection`
        """
        model = InvoiceItemsCollection()
        if include_optional:
            return InvoiceItemsCollection(
                data = [
                    jubladb_api.models.invoice_items_resource.invoice_items_resource(
                        id = '81', 
                        type = 'invoice_items', 
                        attributes = jubladb_api.models.invoice_items.invoice_items(
                            invoice_id = 56, 
                            name = '', 
                            description = '', 
                            unit_cost = 1.337, 
                            vat_rate = 1.337, 
                            cost = 56, 
                            count = 56, 
                            cost_center = '', 
                            account = '', ), 
                        relationships = jubladb_api.models.invoice_items_relationships.invoice_items_relationships(
                            invoice = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(
                                links = { }, 
                                data = jubladb_api.models.jsonapi_linkage.jsonapi_linkage(
                                    type = 'additional_emails', 
                                    meta = { }, 
                                    id = '44', ), 
                                meta = { }, ), ), 
                        links = {
                            'key' : null
                            }, )
                    ],
                included = [
                    jubladb_api.models.jsonapi_resource.jsonapi_resource()
                    ],
                meta = { },
                links = None,
                jsonapi = jubladb_api.models.jsonapi_jsonapi.jsonapi_jsonapi(
                    version = '1.0', 
                    meta = { }, )
            )
        else:
            return InvoiceItemsCollection(
        )
        """

    def testInvoiceItemsCollection(self):
        """Test InvoiceItemsCollection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
