# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import date, datetime
from pydantic import Field, StrictInt, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from jubladb_api.models.groups_readable_attribute import GroupsReadableAttribute
from jubladb_api.models.jsonapi_info import JsonapiInfo
from jubladb_api.models.people_readable_attribute import PeopleReadableAttribute
from jubladb_api.models.roles_collection import RolesCollection
from jubladb_api.models.roles_readable_attribute import RolesReadableAttribute
from jubladb_api.models.roles_request import RolesRequest
from jubladb_api.models.roles_single import RolesSingle

from jubladb_api.api_client import ApiClient, RequestSerialized
from jubladb_api.api_response import ApiResponse
from jubladb_api.rest import RESTResponseType


class RolesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_role(
        self,
        roles_request: RolesRequest,
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RolesSingle:
        """Create Role


        :param roles_request: (required)
        :type roles_request: RolesRequest
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_role_serialize(
            roles_request=roles_request,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "RolesSingle",
            '202': None,
            '204': None,
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '422': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_role_with_http_info(
        self,
        roles_request: RolesRequest,
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> ApiResponse[RolesSingle]:
        """Create Role


        :param roles_request: (required)
        :type roles_request: RolesRequest
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_role_serialize(
            roles_request=roles_request,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "RolesSingle",
            '202': None,
            '204': None,
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '422': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_role_without_preload_content(
        self,
        roles_request: RolesRequest,
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RESTResponseType:
        """Create Role


        :param roles_request: (required)
        :type roles_request: RolesRequest
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_role_serialize(
            roles_request=roles_request,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "RolesSingle",
            '202': None,
            '204': None,
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '422': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_role_serialize(
        self,
        roles_request,
        include,
        sort,
        fields_roles,
        filter_id_eq,
        filter_id_not_eq,
        filter_id_gt,
        filter_id_gte,
        filter_id_lt,
        filter_id_lte,
        filter_created_at_eq,
        filter_created_at_not_eq,
        filter_created_at_gt,
        filter_created_at_gte,
        filter_created_at_lt,
        filter_created_at_lte,
        filter_updated_at_eq,
        filter_updated_at_not_eq,
        filter_updated_at_gt,
        filter_updated_at_gte,
        filter_updated_at_lt,
        filter_updated_at_lte,
        filter_start_on_eq,
        filter_start_on_not_eq,
        filter_start_on_gt,
        filter_start_on_gte,
        filter_start_on_lt,
        filter_start_on_lte,
        filter_end_on_eq,
        filter_end_on_not_eq,
        filter_end_on_gt,
        filter_end_on_gte,
        filter_end_on_lt,
        filter_end_on_lte,
        filter_person_id_eq,
        filter_person_id_not_eq,
        filter_person_id_gt,
        filter_person_id_gte,
        filter_person_id_lt,
        filter_person_id_lte,
        filter_group_id_eq,
        filter_group_id_not_eq,
        filter_group_id_gt,
        filter_group_id_gte,
        filter_group_id_lt,
        filter_group_id_lte,
        filter_type_eq,
        filter_type_not_eq,
        filter_type_eql,
        filter_type_not_eql,
        filter_type_prefix,
        filter_type_not_prefix,
        filter_type_suffix,
        filter_type_not_suffix,
        filter_type_match,
        filter_type_not_match,
        filter_label_eq,
        filter_label_not_eq,
        filter_label_eql,
        filter_label_not_eql,
        filter_label_prefix,
        filter_label_not_prefix,
        filter_label_suffix,
        filter_label_not_suffix,
        filter_label_match,
        filter_label_not_match,
        fields_people,
        fields_groups,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'include': 'csv',
            'sort': 'csv',
            'fields[roles]': 'csv',
            'filter[id][eq]': 'csv',
            'filter[id][not_eq]': 'csv',
            'filter[id][gt]': 'csv',
            'filter[id][gte]': 'csv',
            'filter[id][lt]': 'csv',
            'filter[id][lte]': 'csv',
            'filter[created_at][eq]': 'csv',
            'filter[created_at][not_eq]': 'csv',
            'filter[created_at][gt]': 'csv',
            'filter[created_at][gte]': 'csv',
            'filter[created_at][lt]': 'csv',
            'filter[created_at][lte]': 'csv',
            'filter[updated_at][eq]': 'csv',
            'filter[updated_at][not_eq]': 'csv',
            'filter[updated_at][gt]': 'csv',
            'filter[updated_at][gte]': 'csv',
            'filter[updated_at][lt]': 'csv',
            'filter[updated_at][lte]': 'csv',
            'filter[start_on][eq]': 'csv',
            'filter[start_on][not_eq]': 'csv',
            'filter[start_on][gt]': 'csv',
            'filter[start_on][gte]': 'csv',
            'filter[start_on][lt]': 'csv',
            'filter[start_on][lte]': 'csv',
            'filter[end_on][eq]': 'csv',
            'filter[end_on][not_eq]': 'csv',
            'filter[end_on][gt]': 'csv',
            'filter[end_on][gte]': 'csv',
            'filter[end_on][lt]': 'csv',
            'filter[end_on][lte]': 'csv',
            'filter[person_id][eq]': 'csv',
            'filter[person_id][not_eq]': 'csv',
            'filter[person_id][gt]': 'csv',
            'filter[person_id][gte]': 'csv',
            'filter[person_id][lt]': 'csv',
            'filter[person_id][lte]': 'csv',
            'filter[group_id][eq]': 'csv',
            'filter[group_id][not_eq]': 'csv',
            'filter[group_id][gt]': 'csv',
            'filter[group_id][gte]': 'csv',
            'filter[group_id][lt]': 'csv',
            'filter[group_id][lte]': 'csv',
            'filter[type][eq]': 'csv',
            'filter[type][not_eq]': 'csv',
            'filter[type][eql]': 'csv',
            'filter[type][not_eql]': 'csv',
            'filter[type][prefix]': 'csv',
            'filter[type][not_prefix]': 'csv',
            'filter[type][suffix]': 'csv',
            'filter[type][not_suffix]': 'csv',
            'filter[type][match]': 'csv',
            'filter[type][not_match]': 'csv',
            'filter[label][eq]': 'csv',
            'filter[label][not_eq]': 'csv',
            'filter[label][eql]': 'csv',
            'filter[label][not_eql]': 'csv',
            'filter[label][prefix]': 'csv',
            'filter[label][not_prefix]': 'csv',
            'filter[label][suffix]': 'csv',
            'filter[label][not_suffix]': 'csv',
            'filter[label][match]': 'csv',
            'filter[label][not_match]': 'csv',
            'fields[people]': 'csv',
            'fields[groups]': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters

        if _additional_query_params is not None:
            _query_params.extend((key, value) for key, value in _additional_query_params.items())

        if include is not None:
            
            _query_params.append(('include', include))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if fields_roles is not None:
            
            _query_params.append(('fields[roles]', fields_roles))
            
        if filter_id_eq is not None:
            
            _query_params.append(('filter[id][eq]', filter_id_eq))
            
        if filter_id_not_eq is not None:
            
            _query_params.append(('filter[id][not_eq]', filter_id_not_eq))
            
        if filter_id_gt is not None:
            
            _query_params.append(('filter[id][gt]', filter_id_gt))
            
        if filter_id_gte is not None:
            
            _query_params.append(('filter[id][gte]', filter_id_gte))
            
        if filter_id_lt is not None:
            
            _query_params.append(('filter[id][lt]', filter_id_lt))
            
        if filter_id_lte is not None:
            
            _query_params.append(('filter[id][lte]', filter_id_lte))
            
        if filter_created_at_eq is not None:
            
            _query_params.append(('filter[created_at][eq]', filter_created_at_eq))
            
        if filter_created_at_not_eq is not None:
            
            _query_params.append(('filter[created_at][not_eq]', filter_created_at_not_eq))
            
        if filter_created_at_gt is not None:
            
            _query_params.append(('filter[created_at][gt]', filter_created_at_gt))
            
        if filter_created_at_gte is not None:
            
            _query_params.append(('filter[created_at][gte]', filter_created_at_gte))
            
        if filter_created_at_lt is not None:
            
            _query_params.append(('filter[created_at][lt]', filter_created_at_lt))
            
        if filter_created_at_lte is not None:
            
            _query_params.append(('filter[created_at][lte]', filter_created_at_lte))
            
        if filter_updated_at_eq is not None:
            
            _query_params.append(('filter[updated_at][eq]', filter_updated_at_eq))
            
        if filter_updated_at_not_eq is not None:
            
            _query_params.append(('filter[updated_at][not_eq]', filter_updated_at_not_eq))
            
        if filter_updated_at_gt is not None:
            
            _query_params.append(('filter[updated_at][gt]', filter_updated_at_gt))
            
        if filter_updated_at_gte is not None:
            
            _query_params.append(('filter[updated_at][gte]', filter_updated_at_gte))
            
        if filter_updated_at_lt is not None:
            
            _query_params.append(('filter[updated_at][lt]', filter_updated_at_lt))
            
        if filter_updated_at_lte is not None:
            
            _query_params.append(('filter[updated_at][lte]', filter_updated_at_lte))
            
        if filter_start_on_eq is not None:
            
            _query_params.append(('filter[start_on][eq]', filter_start_on_eq))
            
        if filter_start_on_not_eq is not None:
            
            _query_params.append(('filter[start_on][not_eq]', filter_start_on_not_eq))
            
        if filter_start_on_gt is not None:
            
            _query_params.append(('filter[start_on][gt]', filter_start_on_gt))
            
        if filter_start_on_gte is not None:
            
            _query_params.append(('filter[start_on][gte]', filter_start_on_gte))
            
        if filter_start_on_lt is not None:
            
            _query_params.append(('filter[start_on][lt]', filter_start_on_lt))
            
        if filter_start_on_lte is not None:
            
            _query_params.append(('filter[start_on][lte]', filter_start_on_lte))
            
        if filter_end_on_eq is not None:
            
            _query_params.append(('filter[end_on][eq]', filter_end_on_eq))
            
        if filter_end_on_not_eq is not None:
            
            _query_params.append(('filter[end_on][not_eq]', filter_end_on_not_eq))
            
        if filter_end_on_gt is not None:
            
            _query_params.append(('filter[end_on][gt]', filter_end_on_gt))
            
        if filter_end_on_gte is not None:
            
            _query_params.append(('filter[end_on][gte]', filter_end_on_gte))
            
        if filter_end_on_lt is not None:
            
            _query_params.append(('filter[end_on][lt]', filter_end_on_lt))
            
        if filter_end_on_lte is not None:
            
            _query_params.append(('filter[end_on][lte]', filter_end_on_lte))
            
        if filter_person_id_eq is not None:
            
            _query_params.append(('filter[person_id][eq]', filter_person_id_eq))
            
        if filter_person_id_not_eq is not None:
            
            _query_params.append(('filter[person_id][not_eq]', filter_person_id_not_eq))
            
        if filter_person_id_gt is not None:
            
            _query_params.append(('filter[person_id][gt]', filter_person_id_gt))
            
        if filter_person_id_gte is not None:
            
            _query_params.append(('filter[person_id][gte]', filter_person_id_gte))
            
        if filter_person_id_lt is not None:
            
            _query_params.append(('filter[person_id][lt]', filter_person_id_lt))
            
        if filter_person_id_lte is not None:
            
            _query_params.append(('filter[person_id][lte]', filter_person_id_lte))
            
        if filter_group_id_eq is not None:
            
            _query_params.append(('filter[group_id][eq]', filter_group_id_eq))
            
        if filter_group_id_not_eq is not None:
            
            _query_params.append(('filter[group_id][not_eq]', filter_group_id_not_eq))
            
        if filter_group_id_gt is not None:
            
            _query_params.append(('filter[group_id][gt]', filter_group_id_gt))
            
        if filter_group_id_gte is not None:
            
            _query_params.append(('filter[group_id][gte]', filter_group_id_gte))
            
        if filter_group_id_lt is not None:
            
            _query_params.append(('filter[group_id][lt]', filter_group_id_lt))
            
        if filter_group_id_lte is not None:
            
            _query_params.append(('filter[group_id][lte]', filter_group_id_lte))
            
        if filter_type_eq is not None:
            
            _query_params.append(('filter[type][eq]', filter_type_eq))
            
        if filter_type_not_eq is not None:
            
            _query_params.append(('filter[type][not_eq]', filter_type_not_eq))
            
        if filter_type_eql is not None:
            
            _query_params.append(('filter[type][eql]', filter_type_eql))
            
        if filter_type_not_eql is not None:
            
            _query_params.append(('filter[type][not_eql]', filter_type_not_eql))
            
        if filter_type_prefix is not None:
            
            _query_params.append(('filter[type][prefix]', filter_type_prefix))
            
        if filter_type_not_prefix is not None:
            
            _query_params.append(('filter[type][not_prefix]', filter_type_not_prefix))
            
        if filter_type_suffix is not None:
            
            _query_params.append(('filter[type][suffix]', filter_type_suffix))
            
        if filter_type_not_suffix is not None:
            
            _query_params.append(('filter[type][not_suffix]', filter_type_not_suffix))
            
        if filter_type_match is not None:
            
            _query_params.append(('filter[type][match]', filter_type_match))
            
        if filter_type_not_match is not None:
            
            _query_params.append(('filter[type][not_match]', filter_type_not_match))
            
        if filter_label_eq is not None:
            
            _query_params.append(('filter[label][eq]', filter_label_eq))
            
        if filter_label_not_eq is not None:
            
            _query_params.append(('filter[label][not_eq]', filter_label_not_eq))
            
        if filter_label_eql is not None:
            
            _query_params.append(('filter[label][eql]', filter_label_eql))
            
        if filter_label_not_eql is not None:
            
            _query_params.append(('filter[label][not_eql]', filter_label_not_eql))
            
        if filter_label_prefix is not None:
            
            _query_params.append(('filter[label][prefix]', filter_label_prefix))
            
        if filter_label_not_prefix is not None:
            
            _query_params.append(('filter[label][not_prefix]', filter_label_not_prefix))
            
        if filter_label_suffix is not None:
            
            _query_params.append(('filter[label][suffix]', filter_label_suffix))
            
        if filter_label_not_suffix is not None:
            
            _query_params.append(('filter[label][not_suffix]', filter_label_not_suffix))
            
        if filter_label_match is not None:
            
            _query_params.append(('filter[label][match]', filter_label_match))
            
        if filter_label_not_match is not None:
            
            _query_params.append(('filter[label][not_match]', filter_label_not_match))
            
        if fields_people is not None:
            
            _query_params.append(('fields[people]', fields_people))
            
        if fields_groups is not None:
            
            _query_params.append(('fields[groups]', fields_groups))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if roles_request is not None:
            _body_params = roles_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/vnd.api+json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/vnd.api+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ServiceTokenAuthHeader', 
            'ServiceTokenAuthParam'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/roles',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_role(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> JsonapiInfo:
        """Destroy Role


        :param id: ID of the resource (required)
        :type id: str
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_role_serialize(
            id=id,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "JsonapiInfo",
            '202': None,
            '204': None,
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_role_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> ApiResponse[JsonapiInfo]:
        """Destroy Role


        :param id: ID of the resource (required)
        :type id: str
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_role_serialize(
            id=id,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "JsonapiInfo",
            '202': None,
            '204': None,
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_role_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RESTResponseType:
        """Destroy Role


        :param id: ID of the resource (required)
        :type id: str
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_role_serialize(
            id=id,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "JsonapiInfo",
            '202': None,
            '204': None,
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_role_serialize(
        self,
        id,
        include,
        sort,
        fields_roles,
        filter_id_eq,
        filter_id_not_eq,
        filter_id_gt,
        filter_id_gte,
        filter_id_lt,
        filter_id_lte,
        filter_created_at_eq,
        filter_created_at_not_eq,
        filter_created_at_gt,
        filter_created_at_gte,
        filter_created_at_lt,
        filter_created_at_lte,
        filter_updated_at_eq,
        filter_updated_at_not_eq,
        filter_updated_at_gt,
        filter_updated_at_gte,
        filter_updated_at_lt,
        filter_updated_at_lte,
        filter_start_on_eq,
        filter_start_on_not_eq,
        filter_start_on_gt,
        filter_start_on_gte,
        filter_start_on_lt,
        filter_start_on_lte,
        filter_end_on_eq,
        filter_end_on_not_eq,
        filter_end_on_gt,
        filter_end_on_gte,
        filter_end_on_lt,
        filter_end_on_lte,
        filter_person_id_eq,
        filter_person_id_not_eq,
        filter_person_id_gt,
        filter_person_id_gte,
        filter_person_id_lt,
        filter_person_id_lte,
        filter_group_id_eq,
        filter_group_id_not_eq,
        filter_group_id_gt,
        filter_group_id_gte,
        filter_group_id_lt,
        filter_group_id_lte,
        filter_type_eq,
        filter_type_not_eq,
        filter_type_eql,
        filter_type_not_eql,
        filter_type_prefix,
        filter_type_not_prefix,
        filter_type_suffix,
        filter_type_not_suffix,
        filter_type_match,
        filter_type_not_match,
        filter_label_eq,
        filter_label_not_eq,
        filter_label_eql,
        filter_label_not_eql,
        filter_label_prefix,
        filter_label_not_prefix,
        filter_label_suffix,
        filter_label_not_suffix,
        filter_label_match,
        filter_label_not_match,
        fields_people,
        fields_groups,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'include': 'csv',
            'sort': 'csv',
            'fields[roles]': 'csv',
            'filter[id][eq]': 'csv',
            'filter[id][not_eq]': 'csv',
            'filter[id][gt]': 'csv',
            'filter[id][gte]': 'csv',
            'filter[id][lt]': 'csv',
            'filter[id][lte]': 'csv',
            'filter[created_at][eq]': 'csv',
            'filter[created_at][not_eq]': 'csv',
            'filter[created_at][gt]': 'csv',
            'filter[created_at][gte]': 'csv',
            'filter[created_at][lt]': 'csv',
            'filter[created_at][lte]': 'csv',
            'filter[updated_at][eq]': 'csv',
            'filter[updated_at][not_eq]': 'csv',
            'filter[updated_at][gt]': 'csv',
            'filter[updated_at][gte]': 'csv',
            'filter[updated_at][lt]': 'csv',
            'filter[updated_at][lte]': 'csv',
            'filter[start_on][eq]': 'csv',
            'filter[start_on][not_eq]': 'csv',
            'filter[start_on][gt]': 'csv',
            'filter[start_on][gte]': 'csv',
            'filter[start_on][lt]': 'csv',
            'filter[start_on][lte]': 'csv',
            'filter[end_on][eq]': 'csv',
            'filter[end_on][not_eq]': 'csv',
            'filter[end_on][gt]': 'csv',
            'filter[end_on][gte]': 'csv',
            'filter[end_on][lt]': 'csv',
            'filter[end_on][lte]': 'csv',
            'filter[person_id][eq]': 'csv',
            'filter[person_id][not_eq]': 'csv',
            'filter[person_id][gt]': 'csv',
            'filter[person_id][gte]': 'csv',
            'filter[person_id][lt]': 'csv',
            'filter[person_id][lte]': 'csv',
            'filter[group_id][eq]': 'csv',
            'filter[group_id][not_eq]': 'csv',
            'filter[group_id][gt]': 'csv',
            'filter[group_id][gte]': 'csv',
            'filter[group_id][lt]': 'csv',
            'filter[group_id][lte]': 'csv',
            'filter[type][eq]': 'csv',
            'filter[type][not_eq]': 'csv',
            'filter[type][eql]': 'csv',
            'filter[type][not_eql]': 'csv',
            'filter[type][prefix]': 'csv',
            'filter[type][not_prefix]': 'csv',
            'filter[type][suffix]': 'csv',
            'filter[type][not_suffix]': 'csv',
            'filter[type][match]': 'csv',
            'filter[type][not_match]': 'csv',
            'filter[label][eq]': 'csv',
            'filter[label][not_eq]': 'csv',
            'filter[label][eql]': 'csv',
            'filter[label][not_eql]': 'csv',
            'filter[label][prefix]': 'csv',
            'filter[label][not_prefix]': 'csv',
            'filter[label][suffix]': 'csv',
            'filter[label][not_suffix]': 'csv',
            'filter[label][match]': 'csv',
            'filter[label][not_match]': 'csv',
            'fields[people]': 'csv',
            'fields[groups]': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters

        if _additional_query_params is not None:
            _query_params.extend((key, value) for key, value in _additional_query_params.items())

        if include is not None:
            
            _query_params.append(('include', include))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if fields_roles is not None:
            
            _query_params.append(('fields[roles]', fields_roles))
            
        if filter_id_eq is not None:
            
            _query_params.append(('filter[id][eq]', filter_id_eq))
            
        if filter_id_not_eq is not None:
            
            _query_params.append(('filter[id][not_eq]', filter_id_not_eq))
            
        if filter_id_gt is not None:
            
            _query_params.append(('filter[id][gt]', filter_id_gt))
            
        if filter_id_gte is not None:
            
            _query_params.append(('filter[id][gte]', filter_id_gte))
            
        if filter_id_lt is not None:
            
            _query_params.append(('filter[id][lt]', filter_id_lt))
            
        if filter_id_lte is not None:
            
            _query_params.append(('filter[id][lte]', filter_id_lte))
            
        if filter_created_at_eq is not None:
            
            _query_params.append(('filter[created_at][eq]', filter_created_at_eq))
            
        if filter_created_at_not_eq is not None:
            
            _query_params.append(('filter[created_at][not_eq]', filter_created_at_not_eq))
            
        if filter_created_at_gt is not None:
            
            _query_params.append(('filter[created_at][gt]', filter_created_at_gt))
            
        if filter_created_at_gte is not None:
            
            _query_params.append(('filter[created_at][gte]', filter_created_at_gte))
            
        if filter_created_at_lt is not None:
            
            _query_params.append(('filter[created_at][lt]', filter_created_at_lt))
            
        if filter_created_at_lte is not None:
            
            _query_params.append(('filter[created_at][lte]', filter_created_at_lte))
            
        if filter_updated_at_eq is not None:
            
            _query_params.append(('filter[updated_at][eq]', filter_updated_at_eq))
            
        if filter_updated_at_not_eq is not None:
            
            _query_params.append(('filter[updated_at][not_eq]', filter_updated_at_not_eq))
            
        if filter_updated_at_gt is not None:
            
            _query_params.append(('filter[updated_at][gt]', filter_updated_at_gt))
            
        if filter_updated_at_gte is not None:
            
            _query_params.append(('filter[updated_at][gte]', filter_updated_at_gte))
            
        if filter_updated_at_lt is not None:
            
            _query_params.append(('filter[updated_at][lt]', filter_updated_at_lt))
            
        if filter_updated_at_lte is not None:
            
            _query_params.append(('filter[updated_at][lte]', filter_updated_at_lte))
            
        if filter_start_on_eq is not None:
            
            _query_params.append(('filter[start_on][eq]', filter_start_on_eq))
            
        if filter_start_on_not_eq is not None:
            
            _query_params.append(('filter[start_on][not_eq]', filter_start_on_not_eq))
            
        if filter_start_on_gt is not None:
            
            _query_params.append(('filter[start_on][gt]', filter_start_on_gt))
            
        if filter_start_on_gte is not None:
            
            _query_params.append(('filter[start_on][gte]', filter_start_on_gte))
            
        if filter_start_on_lt is not None:
            
            _query_params.append(('filter[start_on][lt]', filter_start_on_lt))
            
        if filter_start_on_lte is not None:
            
            _query_params.append(('filter[start_on][lte]', filter_start_on_lte))
            
        if filter_end_on_eq is not None:
            
            _query_params.append(('filter[end_on][eq]', filter_end_on_eq))
            
        if filter_end_on_not_eq is not None:
            
            _query_params.append(('filter[end_on][not_eq]', filter_end_on_not_eq))
            
        if filter_end_on_gt is not None:
            
            _query_params.append(('filter[end_on][gt]', filter_end_on_gt))
            
        if filter_end_on_gte is not None:
            
            _query_params.append(('filter[end_on][gte]', filter_end_on_gte))
            
        if filter_end_on_lt is not None:
            
            _query_params.append(('filter[end_on][lt]', filter_end_on_lt))
            
        if filter_end_on_lte is not None:
            
            _query_params.append(('filter[end_on][lte]', filter_end_on_lte))
            
        if filter_person_id_eq is not None:
            
            _query_params.append(('filter[person_id][eq]', filter_person_id_eq))
            
        if filter_person_id_not_eq is not None:
            
            _query_params.append(('filter[person_id][not_eq]', filter_person_id_not_eq))
            
        if filter_person_id_gt is not None:
            
            _query_params.append(('filter[person_id][gt]', filter_person_id_gt))
            
        if filter_person_id_gte is not None:
            
            _query_params.append(('filter[person_id][gte]', filter_person_id_gte))
            
        if filter_person_id_lt is not None:
            
            _query_params.append(('filter[person_id][lt]', filter_person_id_lt))
            
        if filter_person_id_lte is not None:
            
            _query_params.append(('filter[person_id][lte]', filter_person_id_lte))
            
        if filter_group_id_eq is not None:
            
            _query_params.append(('filter[group_id][eq]', filter_group_id_eq))
            
        if filter_group_id_not_eq is not None:
            
            _query_params.append(('filter[group_id][not_eq]', filter_group_id_not_eq))
            
        if filter_group_id_gt is not None:
            
            _query_params.append(('filter[group_id][gt]', filter_group_id_gt))
            
        if filter_group_id_gte is not None:
            
            _query_params.append(('filter[group_id][gte]', filter_group_id_gte))
            
        if filter_group_id_lt is not None:
            
            _query_params.append(('filter[group_id][lt]', filter_group_id_lt))
            
        if filter_group_id_lte is not None:
            
            _query_params.append(('filter[group_id][lte]', filter_group_id_lte))
            
        if filter_type_eq is not None:
            
            _query_params.append(('filter[type][eq]', filter_type_eq))
            
        if filter_type_not_eq is not None:
            
            _query_params.append(('filter[type][not_eq]', filter_type_not_eq))
            
        if filter_type_eql is not None:
            
            _query_params.append(('filter[type][eql]', filter_type_eql))
            
        if filter_type_not_eql is not None:
            
            _query_params.append(('filter[type][not_eql]', filter_type_not_eql))
            
        if filter_type_prefix is not None:
            
            _query_params.append(('filter[type][prefix]', filter_type_prefix))
            
        if filter_type_not_prefix is not None:
            
            _query_params.append(('filter[type][not_prefix]', filter_type_not_prefix))
            
        if filter_type_suffix is not None:
            
            _query_params.append(('filter[type][suffix]', filter_type_suffix))
            
        if filter_type_not_suffix is not None:
            
            _query_params.append(('filter[type][not_suffix]', filter_type_not_suffix))
            
        if filter_type_match is not None:
            
            _query_params.append(('filter[type][match]', filter_type_match))
            
        if filter_type_not_match is not None:
            
            _query_params.append(('filter[type][not_match]', filter_type_not_match))
            
        if filter_label_eq is not None:
            
            _query_params.append(('filter[label][eq]', filter_label_eq))
            
        if filter_label_not_eq is not None:
            
            _query_params.append(('filter[label][not_eq]', filter_label_not_eq))
            
        if filter_label_eql is not None:
            
            _query_params.append(('filter[label][eql]', filter_label_eql))
            
        if filter_label_not_eql is not None:
            
            _query_params.append(('filter[label][not_eql]', filter_label_not_eql))
            
        if filter_label_prefix is not None:
            
            _query_params.append(('filter[label][prefix]', filter_label_prefix))
            
        if filter_label_not_prefix is not None:
            
            _query_params.append(('filter[label][not_prefix]', filter_label_not_prefix))
            
        if filter_label_suffix is not None:
            
            _query_params.append(('filter[label][suffix]', filter_label_suffix))
            
        if filter_label_not_suffix is not None:
            
            _query_params.append(('filter[label][not_suffix]', filter_label_not_suffix))
            
        if filter_label_match is not None:
            
            _query_params.append(('filter[label][match]', filter_label_match))
            
        if filter_label_not_match is not None:
            
            _query_params.append(('filter[label][not_match]', filter_label_not_match))
            
        if fields_people is not None:
            
            _query_params.append(('fields[people]', fields_people))
            
        if fields_groups is not None:
            
            _query_params.append(('fields[groups]', fields_groups))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/vnd.api+json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ServiceTokenAuthHeader', 
            'ServiceTokenAuthParam'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/roles/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_role(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RolesSingle:
        """Fetch Role


        :param id: ID of the resource (required)
        :type id: str
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_role_serialize(
            id=id,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RolesSingle",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_role_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> ApiResponse[RolesSingle]:
        """Fetch Role


        :param id: ID of the resource (required)
        :type id: str
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_role_serialize(
            id=id,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RolesSingle",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_role_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RESTResponseType:
        """Fetch Role


        :param id: ID of the resource (required)
        :type id: str
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_role_serialize(
            id=id,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RolesSingle",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_role_serialize(
        self,
        id,
        include,
        sort,
        fields_roles,
        filter_id_eq,
        filter_id_not_eq,
        filter_id_gt,
        filter_id_gte,
        filter_id_lt,
        filter_id_lte,
        filter_created_at_eq,
        filter_created_at_not_eq,
        filter_created_at_gt,
        filter_created_at_gte,
        filter_created_at_lt,
        filter_created_at_lte,
        filter_updated_at_eq,
        filter_updated_at_not_eq,
        filter_updated_at_gt,
        filter_updated_at_gte,
        filter_updated_at_lt,
        filter_updated_at_lte,
        filter_start_on_eq,
        filter_start_on_not_eq,
        filter_start_on_gt,
        filter_start_on_gte,
        filter_start_on_lt,
        filter_start_on_lte,
        filter_end_on_eq,
        filter_end_on_not_eq,
        filter_end_on_gt,
        filter_end_on_gte,
        filter_end_on_lt,
        filter_end_on_lte,
        filter_person_id_eq,
        filter_person_id_not_eq,
        filter_person_id_gt,
        filter_person_id_gte,
        filter_person_id_lt,
        filter_person_id_lte,
        filter_group_id_eq,
        filter_group_id_not_eq,
        filter_group_id_gt,
        filter_group_id_gte,
        filter_group_id_lt,
        filter_group_id_lte,
        filter_type_eq,
        filter_type_not_eq,
        filter_type_eql,
        filter_type_not_eql,
        filter_type_prefix,
        filter_type_not_prefix,
        filter_type_suffix,
        filter_type_not_suffix,
        filter_type_match,
        filter_type_not_match,
        filter_label_eq,
        filter_label_not_eq,
        filter_label_eql,
        filter_label_not_eql,
        filter_label_prefix,
        filter_label_not_prefix,
        filter_label_suffix,
        filter_label_not_suffix,
        filter_label_match,
        filter_label_not_match,
        fields_people,
        fields_groups,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'include': 'csv',
            'sort': 'csv',
            'fields[roles]': 'csv',
            'filter[id][eq]': 'csv',
            'filter[id][not_eq]': 'csv',
            'filter[id][gt]': 'csv',
            'filter[id][gte]': 'csv',
            'filter[id][lt]': 'csv',
            'filter[id][lte]': 'csv',
            'filter[created_at][eq]': 'csv',
            'filter[created_at][not_eq]': 'csv',
            'filter[created_at][gt]': 'csv',
            'filter[created_at][gte]': 'csv',
            'filter[created_at][lt]': 'csv',
            'filter[created_at][lte]': 'csv',
            'filter[updated_at][eq]': 'csv',
            'filter[updated_at][not_eq]': 'csv',
            'filter[updated_at][gt]': 'csv',
            'filter[updated_at][gte]': 'csv',
            'filter[updated_at][lt]': 'csv',
            'filter[updated_at][lte]': 'csv',
            'filter[start_on][eq]': 'csv',
            'filter[start_on][not_eq]': 'csv',
            'filter[start_on][gt]': 'csv',
            'filter[start_on][gte]': 'csv',
            'filter[start_on][lt]': 'csv',
            'filter[start_on][lte]': 'csv',
            'filter[end_on][eq]': 'csv',
            'filter[end_on][not_eq]': 'csv',
            'filter[end_on][gt]': 'csv',
            'filter[end_on][gte]': 'csv',
            'filter[end_on][lt]': 'csv',
            'filter[end_on][lte]': 'csv',
            'filter[person_id][eq]': 'csv',
            'filter[person_id][not_eq]': 'csv',
            'filter[person_id][gt]': 'csv',
            'filter[person_id][gte]': 'csv',
            'filter[person_id][lt]': 'csv',
            'filter[person_id][lte]': 'csv',
            'filter[group_id][eq]': 'csv',
            'filter[group_id][not_eq]': 'csv',
            'filter[group_id][gt]': 'csv',
            'filter[group_id][gte]': 'csv',
            'filter[group_id][lt]': 'csv',
            'filter[group_id][lte]': 'csv',
            'filter[type][eq]': 'csv',
            'filter[type][not_eq]': 'csv',
            'filter[type][eql]': 'csv',
            'filter[type][not_eql]': 'csv',
            'filter[type][prefix]': 'csv',
            'filter[type][not_prefix]': 'csv',
            'filter[type][suffix]': 'csv',
            'filter[type][not_suffix]': 'csv',
            'filter[type][match]': 'csv',
            'filter[type][not_match]': 'csv',
            'filter[label][eq]': 'csv',
            'filter[label][not_eq]': 'csv',
            'filter[label][eql]': 'csv',
            'filter[label][not_eql]': 'csv',
            'filter[label][prefix]': 'csv',
            'filter[label][not_prefix]': 'csv',
            'filter[label][suffix]': 'csv',
            'filter[label][not_suffix]': 'csv',
            'filter[label][match]': 'csv',
            'filter[label][not_match]': 'csv',
            'fields[people]': 'csv',
            'fields[groups]': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters

        if _additional_query_params is not None:
            _query_params.extend((key, value) for key, value in _additional_query_params.items())

        if include is not None:
            
            _query_params.append(('include', include))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if fields_roles is not None:
            
            _query_params.append(('fields[roles]', fields_roles))
            
        if filter_id_eq is not None:
            
            _query_params.append(('filter[id][eq]', filter_id_eq))
            
        if filter_id_not_eq is not None:
            
            _query_params.append(('filter[id][not_eq]', filter_id_not_eq))
            
        if filter_id_gt is not None:
            
            _query_params.append(('filter[id][gt]', filter_id_gt))
            
        if filter_id_gte is not None:
            
            _query_params.append(('filter[id][gte]', filter_id_gte))
            
        if filter_id_lt is not None:
            
            _query_params.append(('filter[id][lt]', filter_id_lt))
            
        if filter_id_lte is not None:
            
            _query_params.append(('filter[id][lte]', filter_id_lte))
            
        if filter_created_at_eq is not None:
            
            _query_params.append(('filter[created_at][eq]', filter_created_at_eq))
            
        if filter_created_at_not_eq is not None:
            
            _query_params.append(('filter[created_at][not_eq]', filter_created_at_not_eq))
            
        if filter_created_at_gt is not None:
            
            _query_params.append(('filter[created_at][gt]', filter_created_at_gt))
            
        if filter_created_at_gte is not None:
            
            _query_params.append(('filter[created_at][gte]', filter_created_at_gte))
            
        if filter_created_at_lt is not None:
            
            _query_params.append(('filter[created_at][lt]', filter_created_at_lt))
            
        if filter_created_at_lte is not None:
            
            _query_params.append(('filter[created_at][lte]', filter_created_at_lte))
            
        if filter_updated_at_eq is not None:
            
            _query_params.append(('filter[updated_at][eq]', filter_updated_at_eq))
            
        if filter_updated_at_not_eq is not None:
            
            _query_params.append(('filter[updated_at][not_eq]', filter_updated_at_not_eq))
            
        if filter_updated_at_gt is not None:
            
            _query_params.append(('filter[updated_at][gt]', filter_updated_at_gt))
            
        if filter_updated_at_gte is not None:
            
            _query_params.append(('filter[updated_at][gte]', filter_updated_at_gte))
            
        if filter_updated_at_lt is not None:
            
            _query_params.append(('filter[updated_at][lt]', filter_updated_at_lt))
            
        if filter_updated_at_lte is not None:
            
            _query_params.append(('filter[updated_at][lte]', filter_updated_at_lte))
            
        if filter_start_on_eq is not None:
            
            _query_params.append(('filter[start_on][eq]', filter_start_on_eq))
            
        if filter_start_on_not_eq is not None:
            
            _query_params.append(('filter[start_on][not_eq]', filter_start_on_not_eq))
            
        if filter_start_on_gt is not None:
            
            _query_params.append(('filter[start_on][gt]', filter_start_on_gt))
            
        if filter_start_on_gte is not None:
            
            _query_params.append(('filter[start_on][gte]', filter_start_on_gte))
            
        if filter_start_on_lt is not None:
            
            _query_params.append(('filter[start_on][lt]', filter_start_on_lt))
            
        if filter_start_on_lte is not None:
            
            _query_params.append(('filter[start_on][lte]', filter_start_on_lte))
            
        if filter_end_on_eq is not None:
            
            _query_params.append(('filter[end_on][eq]', filter_end_on_eq))
            
        if filter_end_on_not_eq is not None:
            
            _query_params.append(('filter[end_on][not_eq]', filter_end_on_not_eq))
            
        if filter_end_on_gt is not None:
            
            _query_params.append(('filter[end_on][gt]', filter_end_on_gt))
            
        if filter_end_on_gte is not None:
            
            _query_params.append(('filter[end_on][gte]', filter_end_on_gte))
            
        if filter_end_on_lt is not None:
            
            _query_params.append(('filter[end_on][lt]', filter_end_on_lt))
            
        if filter_end_on_lte is not None:
            
            _query_params.append(('filter[end_on][lte]', filter_end_on_lte))
            
        if filter_person_id_eq is not None:
            
            _query_params.append(('filter[person_id][eq]', filter_person_id_eq))
            
        if filter_person_id_not_eq is not None:
            
            _query_params.append(('filter[person_id][not_eq]', filter_person_id_not_eq))
            
        if filter_person_id_gt is not None:
            
            _query_params.append(('filter[person_id][gt]', filter_person_id_gt))
            
        if filter_person_id_gte is not None:
            
            _query_params.append(('filter[person_id][gte]', filter_person_id_gte))
            
        if filter_person_id_lt is not None:
            
            _query_params.append(('filter[person_id][lt]', filter_person_id_lt))
            
        if filter_person_id_lte is not None:
            
            _query_params.append(('filter[person_id][lte]', filter_person_id_lte))
            
        if filter_group_id_eq is not None:
            
            _query_params.append(('filter[group_id][eq]', filter_group_id_eq))
            
        if filter_group_id_not_eq is not None:
            
            _query_params.append(('filter[group_id][not_eq]', filter_group_id_not_eq))
            
        if filter_group_id_gt is not None:
            
            _query_params.append(('filter[group_id][gt]', filter_group_id_gt))
            
        if filter_group_id_gte is not None:
            
            _query_params.append(('filter[group_id][gte]', filter_group_id_gte))
            
        if filter_group_id_lt is not None:
            
            _query_params.append(('filter[group_id][lt]', filter_group_id_lt))
            
        if filter_group_id_lte is not None:
            
            _query_params.append(('filter[group_id][lte]', filter_group_id_lte))
            
        if filter_type_eq is not None:
            
            _query_params.append(('filter[type][eq]', filter_type_eq))
            
        if filter_type_not_eq is not None:
            
            _query_params.append(('filter[type][not_eq]', filter_type_not_eq))
            
        if filter_type_eql is not None:
            
            _query_params.append(('filter[type][eql]', filter_type_eql))
            
        if filter_type_not_eql is not None:
            
            _query_params.append(('filter[type][not_eql]', filter_type_not_eql))
            
        if filter_type_prefix is not None:
            
            _query_params.append(('filter[type][prefix]', filter_type_prefix))
            
        if filter_type_not_prefix is not None:
            
            _query_params.append(('filter[type][not_prefix]', filter_type_not_prefix))
            
        if filter_type_suffix is not None:
            
            _query_params.append(('filter[type][suffix]', filter_type_suffix))
            
        if filter_type_not_suffix is not None:
            
            _query_params.append(('filter[type][not_suffix]', filter_type_not_suffix))
            
        if filter_type_match is not None:
            
            _query_params.append(('filter[type][match]', filter_type_match))
            
        if filter_type_not_match is not None:
            
            _query_params.append(('filter[type][not_match]', filter_type_not_match))
            
        if filter_label_eq is not None:
            
            _query_params.append(('filter[label][eq]', filter_label_eq))
            
        if filter_label_not_eq is not None:
            
            _query_params.append(('filter[label][not_eq]', filter_label_not_eq))
            
        if filter_label_eql is not None:
            
            _query_params.append(('filter[label][eql]', filter_label_eql))
            
        if filter_label_not_eql is not None:
            
            _query_params.append(('filter[label][not_eql]', filter_label_not_eql))
            
        if filter_label_prefix is not None:
            
            _query_params.append(('filter[label][prefix]', filter_label_prefix))
            
        if filter_label_not_prefix is not None:
            
            _query_params.append(('filter[label][not_prefix]', filter_label_not_prefix))
            
        if filter_label_suffix is not None:
            
            _query_params.append(('filter[label][suffix]', filter_label_suffix))
            
        if filter_label_not_suffix is not None:
            
            _query_params.append(('filter[label][not_suffix]', filter_label_not_suffix))
            
        if filter_label_match is not None:
            
            _query_params.append(('filter[label][match]', filter_label_match))
            
        if filter_label_not_match is not None:
            
            _query_params.append(('filter[label][not_match]', filter_label_not_match))
            
        if fields_people is not None:
            
            _query_params.append(('fields[people]', fields_people))
            
        if fields_groups is not None:
            
            _query_params.append(('fields[groups]', fields_groups))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/vnd.api+json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ServiceTokenAuthHeader', 
            'ServiceTokenAuthParam'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/roles/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_roles(
        self,
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RolesCollection:
        """List Roles


        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_roles_serialize(
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RolesCollection",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_roles_with_http_info(
        self,
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> ApiResponse[RolesCollection]:
        """List Roles


        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_roles_serialize(
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RolesCollection",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_roles_without_preload_content(
        self,
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RESTResponseType:
        """List Roles


        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_roles_serialize(
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RolesCollection",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_roles_serialize(
        self,
        include,
        sort,
        fields_roles,
        filter_id_eq,
        filter_id_not_eq,
        filter_id_gt,
        filter_id_gte,
        filter_id_lt,
        filter_id_lte,
        filter_created_at_eq,
        filter_created_at_not_eq,
        filter_created_at_gt,
        filter_created_at_gte,
        filter_created_at_lt,
        filter_created_at_lte,
        filter_updated_at_eq,
        filter_updated_at_not_eq,
        filter_updated_at_gt,
        filter_updated_at_gte,
        filter_updated_at_lt,
        filter_updated_at_lte,
        filter_start_on_eq,
        filter_start_on_not_eq,
        filter_start_on_gt,
        filter_start_on_gte,
        filter_start_on_lt,
        filter_start_on_lte,
        filter_end_on_eq,
        filter_end_on_not_eq,
        filter_end_on_gt,
        filter_end_on_gte,
        filter_end_on_lt,
        filter_end_on_lte,
        filter_person_id_eq,
        filter_person_id_not_eq,
        filter_person_id_gt,
        filter_person_id_gte,
        filter_person_id_lt,
        filter_person_id_lte,
        filter_group_id_eq,
        filter_group_id_not_eq,
        filter_group_id_gt,
        filter_group_id_gte,
        filter_group_id_lt,
        filter_group_id_lte,
        filter_type_eq,
        filter_type_not_eq,
        filter_type_eql,
        filter_type_not_eql,
        filter_type_prefix,
        filter_type_not_prefix,
        filter_type_suffix,
        filter_type_not_suffix,
        filter_type_match,
        filter_type_not_match,
        filter_label_eq,
        filter_label_not_eq,
        filter_label_eql,
        filter_label_not_eql,
        filter_label_prefix,
        filter_label_not_prefix,
        filter_label_suffix,
        filter_label_not_suffix,
        filter_label_match,
        filter_label_not_match,
        fields_people,
        fields_groups,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'include': 'csv',
            'sort': 'csv',
            'fields[roles]': 'csv',
            'filter[id][eq]': 'csv',
            'filter[id][not_eq]': 'csv',
            'filter[id][gt]': 'csv',
            'filter[id][gte]': 'csv',
            'filter[id][lt]': 'csv',
            'filter[id][lte]': 'csv',
            'filter[created_at][eq]': 'csv',
            'filter[created_at][not_eq]': 'csv',
            'filter[created_at][gt]': 'csv',
            'filter[created_at][gte]': 'csv',
            'filter[created_at][lt]': 'csv',
            'filter[created_at][lte]': 'csv',
            'filter[updated_at][eq]': 'csv',
            'filter[updated_at][not_eq]': 'csv',
            'filter[updated_at][gt]': 'csv',
            'filter[updated_at][gte]': 'csv',
            'filter[updated_at][lt]': 'csv',
            'filter[updated_at][lte]': 'csv',
            'filter[start_on][eq]': 'csv',
            'filter[start_on][not_eq]': 'csv',
            'filter[start_on][gt]': 'csv',
            'filter[start_on][gte]': 'csv',
            'filter[start_on][lt]': 'csv',
            'filter[start_on][lte]': 'csv',
            'filter[end_on][eq]': 'csv',
            'filter[end_on][not_eq]': 'csv',
            'filter[end_on][gt]': 'csv',
            'filter[end_on][gte]': 'csv',
            'filter[end_on][lt]': 'csv',
            'filter[end_on][lte]': 'csv',
            'filter[person_id][eq]': 'csv',
            'filter[person_id][not_eq]': 'csv',
            'filter[person_id][gt]': 'csv',
            'filter[person_id][gte]': 'csv',
            'filter[person_id][lt]': 'csv',
            'filter[person_id][lte]': 'csv',
            'filter[group_id][eq]': 'csv',
            'filter[group_id][not_eq]': 'csv',
            'filter[group_id][gt]': 'csv',
            'filter[group_id][gte]': 'csv',
            'filter[group_id][lt]': 'csv',
            'filter[group_id][lte]': 'csv',
            'filter[type][eq]': 'csv',
            'filter[type][not_eq]': 'csv',
            'filter[type][eql]': 'csv',
            'filter[type][not_eql]': 'csv',
            'filter[type][prefix]': 'csv',
            'filter[type][not_prefix]': 'csv',
            'filter[type][suffix]': 'csv',
            'filter[type][not_suffix]': 'csv',
            'filter[type][match]': 'csv',
            'filter[type][not_match]': 'csv',
            'filter[label][eq]': 'csv',
            'filter[label][not_eq]': 'csv',
            'filter[label][eql]': 'csv',
            'filter[label][not_eql]': 'csv',
            'filter[label][prefix]': 'csv',
            'filter[label][not_prefix]': 'csv',
            'filter[label][suffix]': 'csv',
            'filter[label][not_suffix]': 'csv',
            'filter[label][match]': 'csv',
            'filter[label][not_match]': 'csv',
            'fields[people]': 'csv',
            'fields[groups]': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters

        if _additional_query_params is not None:
            _query_params.extend((key, value) for key, value in _additional_query_params.items())

        if include is not None:
            
            _query_params.append(('include', include))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if fields_roles is not None:
            
            _query_params.append(('fields[roles]', fields_roles))
            
        if filter_id_eq is not None:
            
            _query_params.append(('filter[id][eq]', filter_id_eq))
            
        if filter_id_not_eq is not None:
            
            _query_params.append(('filter[id][not_eq]', filter_id_not_eq))
            
        if filter_id_gt is not None:
            
            _query_params.append(('filter[id][gt]', filter_id_gt))
            
        if filter_id_gte is not None:
            
            _query_params.append(('filter[id][gte]', filter_id_gte))
            
        if filter_id_lt is not None:
            
            _query_params.append(('filter[id][lt]', filter_id_lt))
            
        if filter_id_lte is not None:
            
            _query_params.append(('filter[id][lte]', filter_id_lte))
            
        if filter_created_at_eq is not None:
            
            _query_params.append(('filter[created_at][eq]', filter_created_at_eq))
            
        if filter_created_at_not_eq is not None:
            
            _query_params.append(('filter[created_at][not_eq]', filter_created_at_not_eq))
            
        if filter_created_at_gt is not None:
            
            _query_params.append(('filter[created_at][gt]', filter_created_at_gt))
            
        if filter_created_at_gte is not None:
            
            _query_params.append(('filter[created_at][gte]', filter_created_at_gte))
            
        if filter_created_at_lt is not None:
            
            _query_params.append(('filter[created_at][lt]', filter_created_at_lt))
            
        if filter_created_at_lte is not None:
            
            _query_params.append(('filter[created_at][lte]', filter_created_at_lte))
            
        if filter_updated_at_eq is not None:
            
            _query_params.append(('filter[updated_at][eq]', filter_updated_at_eq))
            
        if filter_updated_at_not_eq is not None:
            
            _query_params.append(('filter[updated_at][not_eq]', filter_updated_at_not_eq))
            
        if filter_updated_at_gt is not None:
            
            _query_params.append(('filter[updated_at][gt]', filter_updated_at_gt))
            
        if filter_updated_at_gte is not None:
            
            _query_params.append(('filter[updated_at][gte]', filter_updated_at_gte))
            
        if filter_updated_at_lt is not None:
            
            _query_params.append(('filter[updated_at][lt]', filter_updated_at_lt))
            
        if filter_updated_at_lte is not None:
            
            _query_params.append(('filter[updated_at][lte]', filter_updated_at_lte))
            
        if filter_start_on_eq is not None:
            
            _query_params.append(('filter[start_on][eq]', filter_start_on_eq))
            
        if filter_start_on_not_eq is not None:
            
            _query_params.append(('filter[start_on][not_eq]', filter_start_on_not_eq))
            
        if filter_start_on_gt is not None:
            
            _query_params.append(('filter[start_on][gt]', filter_start_on_gt))
            
        if filter_start_on_gte is not None:
            
            _query_params.append(('filter[start_on][gte]', filter_start_on_gte))
            
        if filter_start_on_lt is not None:
            
            _query_params.append(('filter[start_on][lt]', filter_start_on_lt))
            
        if filter_start_on_lte is not None:
            
            _query_params.append(('filter[start_on][lte]', filter_start_on_lte))
            
        if filter_end_on_eq is not None:
            
            _query_params.append(('filter[end_on][eq]', filter_end_on_eq))
            
        if filter_end_on_not_eq is not None:
            
            _query_params.append(('filter[end_on][not_eq]', filter_end_on_not_eq))
            
        if filter_end_on_gt is not None:
            
            _query_params.append(('filter[end_on][gt]', filter_end_on_gt))
            
        if filter_end_on_gte is not None:
            
            _query_params.append(('filter[end_on][gte]', filter_end_on_gte))
            
        if filter_end_on_lt is not None:
            
            _query_params.append(('filter[end_on][lt]', filter_end_on_lt))
            
        if filter_end_on_lte is not None:
            
            _query_params.append(('filter[end_on][lte]', filter_end_on_lte))
            
        if filter_person_id_eq is not None:
            
            _query_params.append(('filter[person_id][eq]', filter_person_id_eq))
            
        if filter_person_id_not_eq is not None:
            
            _query_params.append(('filter[person_id][not_eq]', filter_person_id_not_eq))
            
        if filter_person_id_gt is not None:
            
            _query_params.append(('filter[person_id][gt]', filter_person_id_gt))
            
        if filter_person_id_gte is not None:
            
            _query_params.append(('filter[person_id][gte]', filter_person_id_gte))
            
        if filter_person_id_lt is not None:
            
            _query_params.append(('filter[person_id][lt]', filter_person_id_lt))
            
        if filter_person_id_lte is not None:
            
            _query_params.append(('filter[person_id][lte]', filter_person_id_lte))
            
        if filter_group_id_eq is not None:
            
            _query_params.append(('filter[group_id][eq]', filter_group_id_eq))
            
        if filter_group_id_not_eq is not None:
            
            _query_params.append(('filter[group_id][not_eq]', filter_group_id_not_eq))
            
        if filter_group_id_gt is not None:
            
            _query_params.append(('filter[group_id][gt]', filter_group_id_gt))
            
        if filter_group_id_gte is not None:
            
            _query_params.append(('filter[group_id][gte]', filter_group_id_gte))
            
        if filter_group_id_lt is not None:
            
            _query_params.append(('filter[group_id][lt]', filter_group_id_lt))
            
        if filter_group_id_lte is not None:
            
            _query_params.append(('filter[group_id][lte]', filter_group_id_lte))
            
        if filter_type_eq is not None:
            
            _query_params.append(('filter[type][eq]', filter_type_eq))
            
        if filter_type_not_eq is not None:
            
            _query_params.append(('filter[type][not_eq]', filter_type_not_eq))
            
        if filter_type_eql is not None:
            
            _query_params.append(('filter[type][eql]', filter_type_eql))
            
        if filter_type_not_eql is not None:
            
            _query_params.append(('filter[type][not_eql]', filter_type_not_eql))
            
        if filter_type_prefix is not None:
            
            _query_params.append(('filter[type][prefix]', filter_type_prefix))
            
        if filter_type_not_prefix is not None:
            
            _query_params.append(('filter[type][not_prefix]', filter_type_not_prefix))
            
        if filter_type_suffix is not None:
            
            _query_params.append(('filter[type][suffix]', filter_type_suffix))
            
        if filter_type_not_suffix is not None:
            
            _query_params.append(('filter[type][not_suffix]', filter_type_not_suffix))
            
        if filter_type_match is not None:
            
            _query_params.append(('filter[type][match]', filter_type_match))
            
        if filter_type_not_match is not None:
            
            _query_params.append(('filter[type][not_match]', filter_type_not_match))
            
        if filter_label_eq is not None:
            
            _query_params.append(('filter[label][eq]', filter_label_eq))
            
        if filter_label_not_eq is not None:
            
            _query_params.append(('filter[label][not_eq]', filter_label_not_eq))
            
        if filter_label_eql is not None:
            
            _query_params.append(('filter[label][eql]', filter_label_eql))
            
        if filter_label_not_eql is not None:
            
            _query_params.append(('filter[label][not_eql]', filter_label_not_eql))
            
        if filter_label_prefix is not None:
            
            _query_params.append(('filter[label][prefix]', filter_label_prefix))
            
        if filter_label_not_prefix is not None:
            
            _query_params.append(('filter[label][not_prefix]', filter_label_not_prefix))
            
        if filter_label_suffix is not None:
            
            _query_params.append(('filter[label][suffix]', filter_label_suffix))
            
        if filter_label_not_suffix is not None:
            
            _query_params.append(('filter[label][not_suffix]', filter_label_not_suffix))
            
        if filter_label_match is not None:
            
            _query_params.append(('filter[label][match]', filter_label_match))
            
        if filter_label_not_match is not None:
            
            _query_params.append(('filter[label][not_match]', filter_label_not_match))
            
        if fields_people is not None:
            
            _query_params.append(('fields[people]', fields_people))
            
        if fields_groups is not None:
            
            _query_params.append(('fields[groups]', fields_groups))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/vnd.api+json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ServiceTokenAuthHeader', 
            'ServiceTokenAuthParam'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/roles',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_role(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        roles_request: RolesRequest,
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RolesSingle:
        """Update Role


        :param id: ID of the resource (required)
        :type id: str
        :param roles_request: (required)
        :type roles_request: RolesRequest
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_role_serialize(
            id=id,
            roles_request=roles_request,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RolesSingle",
            '202': None,
            '204': None,
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
            '422': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_role_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        roles_request: RolesRequest,
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> ApiResponse[RolesSingle]:
        """Update Role


        :param id: ID of the resource (required)
        :type id: str
        :param roles_request: (required)
        :type roles_request: RolesRequest
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_role_serialize(
            id=id,
            roles_request=roles_request,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RolesSingle",
            '202': None,
            '204': None,
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
            '422': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_role_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        roles_request: RolesRequest,
        include: Annotated[Optional[List[StrictStr]], Field(description="[Include related resources](https://jsonapi.org/format/#fetching-includes)")] = None,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_roles: Annotated[Optional[List[RolesReadableAttribute]], Field(description="[Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_created_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_not_eq: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_gte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lt: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_updated_at_lte: Annotated[Optional[List[datetime]], Field(description="[Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_start_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_not_eq: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_gte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lt: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_end_on_lte: Annotated[Optional[List[date]], Field(description="[Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_person_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_group_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_type_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eq: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_eql: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_prefix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_suffix: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_label_not_match: Annotated[Optional[List[StrictStr]], Field(description="[Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        fields_people: Annotated[Optional[List[PeopleReadableAttribute]], Field(description="[Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        fields_groups: Annotated[Optional[List[GroupsReadableAttribute]], Field(description="[Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RESTResponseType:
        """Update Role


        :param id: ID of the resource (required)
        :type id: str
        :param roles_request: (required)
        :type roles_request: RolesRequest
        :param include: [Include related resources](https://jsonapi.org/format/#fetching-includes)
        :type include: List[str]
        :param sort: [Sort roles according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_roles: [Include only specified fields of Role in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_roles: List[RolesReadableAttribute]
        :param filter_id_eq: [Filter Role by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Role by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Role by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Role by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Role by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Role by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param filter_created_at_eq: [Filter Role by created_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_eq: List[datetime]
        :param filter_created_at_not_eq: [Filter Role by created_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_not_eq: List[datetime]
        :param filter_created_at_gt: [Filter Role by created_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gt: List[datetime]
        :param filter_created_at_gte: [Filter Role by created_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_gte: List[datetime]
        :param filter_created_at_lt: [Filter Role by created_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lt: List[datetime]
        :param filter_created_at_lte: [Filter Role by created_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_created_at_lte: List[datetime]
        :param filter_updated_at_eq: [Filter Role by updated_at using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_eq: List[datetime]
        :param filter_updated_at_not_eq: [Filter Role by updated_at using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_not_eq: List[datetime]
        :param filter_updated_at_gt: [Filter Role by updated_at using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gt: List[datetime]
        :param filter_updated_at_gte: [Filter Role by updated_at using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_gte: List[datetime]
        :param filter_updated_at_lt: [Filter Role by updated_at using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lt: List[datetime]
        :param filter_updated_at_lte: [Filter Role by updated_at using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_updated_at_lte: List[datetime]
        :param filter_start_on_eq: [Filter Role by start_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_eq: List[date]
        :param filter_start_on_not_eq: [Filter Role by start_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_not_eq: List[date]
        :param filter_start_on_gt: [Filter Role by start_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gt: List[date]
        :param filter_start_on_gte: [Filter Role by start_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_gte: List[date]
        :param filter_start_on_lt: [Filter Role by start_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lt: List[date]
        :param filter_start_on_lte: [Filter Role by start_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_start_on_lte: List[date]
        :param filter_end_on_eq: [Filter Role by end_on using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_eq: List[date]
        :param filter_end_on_not_eq: [Filter Role by end_on using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_not_eq: List[date]
        :param filter_end_on_gt: [Filter Role by end_on using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gt: List[date]
        :param filter_end_on_gte: [Filter Role by end_on using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_gte: List[date]
        :param filter_end_on_lt: [Filter Role by end_on using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lt: List[date]
        :param filter_end_on_lte: [Filter Role by end_on using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_end_on_lte: List[date]
        :param filter_person_id_eq: [Filter Role by person_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_eq: List[int]
        :param filter_person_id_not_eq: [Filter Role by person_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_not_eq: List[int]
        :param filter_person_id_gt: [Filter Role by person_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gt: List[int]
        :param filter_person_id_gte: [Filter Role by person_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_gte: List[int]
        :param filter_person_id_lt: [Filter Role by person_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lt: List[int]
        :param filter_person_id_lte: [Filter Role by person_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_person_id_lte: List[int]
        :param filter_group_id_eq: [Filter Role by group_id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_eq: List[int]
        :param filter_group_id_not_eq: [Filter Role by group_id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_not_eq: List[int]
        :param filter_group_id_gt: [Filter Role by group_id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gt: List[int]
        :param filter_group_id_gte: [Filter Role by group_id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_gte: List[int]
        :param filter_group_id_lt: [Filter Role by group_id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lt: List[int]
        :param filter_group_id_lte: [Filter Role by group_id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_group_id_lte: List[int]
        :param filter_type_eq: [Filter Role by type using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eq: List[str]
        :param filter_type_not_eq: [Filter Role by type using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eq: List[str]
        :param filter_type_eql: [Filter Role by type using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_eql: List[str]
        :param filter_type_not_eql: [Filter Role by type using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_eql: List[str]
        :param filter_type_prefix: [Filter Role by type using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_prefix: List[str]
        :param filter_type_not_prefix: [Filter Role by type using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_prefix: List[str]
        :param filter_type_suffix: [Filter Role by type using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_suffix: List[str]
        :param filter_type_not_suffix: [Filter Role by type using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_suffix: List[str]
        :param filter_type_match: [Filter Role by type using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_match: List[str]
        :param filter_type_not_match: [Filter Role by type using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_type_not_match: List[str]
        :param filter_label_eq: [Filter Role by label using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eq: List[str]
        :param filter_label_not_eq: [Filter Role by label using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eq: List[str]
        :param filter_label_eql: [Filter Role by label using eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_eql: List[str]
        :param filter_label_not_eql: [Filter Role by label using not_eql operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_eql: List[str]
        :param filter_label_prefix: [Filter Role by label using prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_prefix: List[str]
        :param filter_label_not_prefix: [Filter Role by label using not_prefix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_prefix: List[str]
        :param filter_label_suffix: [Filter Role by label using suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_suffix: List[str]
        :param filter_label_not_suffix: [Filter Role by label using not_suffix operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_suffix: List[str]
        :param filter_label_match: [Filter Role by label using match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_match: List[str]
        :param filter_label_not_match: [Filter Role by label using not_match operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_label_not_match: List[str]
        :param fields_people: [Include only specified fields of Person in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_people: List[PeopleReadableAttribute]
        :param fields_groups: [Include only specified fields of Group in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_groups: List[GroupsReadableAttribute]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_role_serialize(
            id=id,
            roles_request=roles_request,
            include=include,
            sort=sort,
            fields_roles=fields_roles,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            filter_created_at_eq=filter_created_at_eq,
            filter_created_at_not_eq=filter_created_at_not_eq,
            filter_created_at_gt=filter_created_at_gt,
            filter_created_at_gte=filter_created_at_gte,
            filter_created_at_lt=filter_created_at_lt,
            filter_created_at_lte=filter_created_at_lte,
            filter_updated_at_eq=filter_updated_at_eq,
            filter_updated_at_not_eq=filter_updated_at_not_eq,
            filter_updated_at_gt=filter_updated_at_gt,
            filter_updated_at_gte=filter_updated_at_gte,
            filter_updated_at_lt=filter_updated_at_lt,
            filter_updated_at_lte=filter_updated_at_lte,
            filter_start_on_eq=filter_start_on_eq,
            filter_start_on_not_eq=filter_start_on_not_eq,
            filter_start_on_gt=filter_start_on_gt,
            filter_start_on_gte=filter_start_on_gte,
            filter_start_on_lt=filter_start_on_lt,
            filter_start_on_lte=filter_start_on_lte,
            filter_end_on_eq=filter_end_on_eq,
            filter_end_on_not_eq=filter_end_on_not_eq,
            filter_end_on_gt=filter_end_on_gt,
            filter_end_on_gte=filter_end_on_gte,
            filter_end_on_lt=filter_end_on_lt,
            filter_end_on_lte=filter_end_on_lte,
            filter_person_id_eq=filter_person_id_eq,
            filter_person_id_not_eq=filter_person_id_not_eq,
            filter_person_id_gt=filter_person_id_gt,
            filter_person_id_gte=filter_person_id_gte,
            filter_person_id_lt=filter_person_id_lt,
            filter_person_id_lte=filter_person_id_lte,
            filter_group_id_eq=filter_group_id_eq,
            filter_group_id_not_eq=filter_group_id_not_eq,
            filter_group_id_gt=filter_group_id_gt,
            filter_group_id_gte=filter_group_id_gte,
            filter_group_id_lt=filter_group_id_lt,
            filter_group_id_lte=filter_group_id_lte,
            filter_type_eq=filter_type_eq,
            filter_type_not_eq=filter_type_not_eq,
            filter_type_eql=filter_type_eql,
            filter_type_not_eql=filter_type_not_eql,
            filter_type_prefix=filter_type_prefix,
            filter_type_not_prefix=filter_type_not_prefix,
            filter_type_suffix=filter_type_suffix,
            filter_type_not_suffix=filter_type_not_suffix,
            filter_type_match=filter_type_match,
            filter_type_not_match=filter_type_not_match,
            filter_label_eq=filter_label_eq,
            filter_label_not_eq=filter_label_not_eq,
            filter_label_eql=filter_label_eql,
            filter_label_not_eql=filter_label_not_eql,
            filter_label_prefix=filter_label_prefix,
            filter_label_not_prefix=filter_label_not_prefix,
            filter_label_suffix=filter_label_suffix,
            filter_label_not_suffix=filter_label_not_suffix,
            filter_label_match=filter_label_match,
            filter_label_not_match=filter_label_not_match,
            fields_people=fields_people,
            fields_groups=fields_groups,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RolesSingle",
            '202': None,
            '204': None,
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
            '422': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_role_serialize(
        self,
        id,
        roles_request,
        include,
        sort,
        fields_roles,
        filter_id_eq,
        filter_id_not_eq,
        filter_id_gt,
        filter_id_gte,
        filter_id_lt,
        filter_id_lte,
        filter_created_at_eq,
        filter_created_at_not_eq,
        filter_created_at_gt,
        filter_created_at_gte,
        filter_created_at_lt,
        filter_created_at_lte,
        filter_updated_at_eq,
        filter_updated_at_not_eq,
        filter_updated_at_gt,
        filter_updated_at_gte,
        filter_updated_at_lt,
        filter_updated_at_lte,
        filter_start_on_eq,
        filter_start_on_not_eq,
        filter_start_on_gt,
        filter_start_on_gte,
        filter_start_on_lt,
        filter_start_on_lte,
        filter_end_on_eq,
        filter_end_on_not_eq,
        filter_end_on_gt,
        filter_end_on_gte,
        filter_end_on_lt,
        filter_end_on_lte,
        filter_person_id_eq,
        filter_person_id_not_eq,
        filter_person_id_gt,
        filter_person_id_gte,
        filter_person_id_lt,
        filter_person_id_lte,
        filter_group_id_eq,
        filter_group_id_not_eq,
        filter_group_id_gt,
        filter_group_id_gte,
        filter_group_id_lt,
        filter_group_id_lte,
        filter_type_eq,
        filter_type_not_eq,
        filter_type_eql,
        filter_type_not_eql,
        filter_type_prefix,
        filter_type_not_prefix,
        filter_type_suffix,
        filter_type_not_suffix,
        filter_type_match,
        filter_type_not_match,
        filter_label_eq,
        filter_label_not_eq,
        filter_label_eql,
        filter_label_not_eql,
        filter_label_prefix,
        filter_label_not_prefix,
        filter_label_suffix,
        filter_label_not_suffix,
        filter_label_match,
        filter_label_not_match,
        fields_people,
        fields_groups,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'include': 'csv',
            'sort': 'csv',
            'fields[roles]': 'csv',
            'filter[id][eq]': 'csv',
            'filter[id][not_eq]': 'csv',
            'filter[id][gt]': 'csv',
            'filter[id][gte]': 'csv',
            'filter[id][lt]': 'csv',
            'filter[id][lte]': 'csv',
            'filter[created_at][eq]': 'csv',
            'filter[created_at][not_eq]': 'csv',
            'filter[created_at][gt]': 'csv',
            'filter[created_at][gte]': 'csv',
            'filter[created_at][lt]': 'csv',
            'filter[created_at][lte]': 'csv',
            'filter[updated_at][eq]': 'csv',
            'filter[updated_at][not_eq]': 'csv',
            'filter[updated_at][gt]': 'csv',
            'filter[updated_at][gte]': 'csv',
            'filter[updated_at][lt]': 'csv',
            'filter[updated_at][lte]': 'csv',
            'filter[start_on][eq]': 'csv',
            'filter[start_on][not_eq]': 'csv',
            'filter[start_on][gt]': 'csv',
            'filter[start_on][gte]': 'csv',
            'filter[start_on][lt]': 'csv',
            'filter[start_on][lte]': 'csv',
            'filter[end_on][eq]': 'csv',
            'filter[end_on][not_eq]': 'csv',
            'filter[end_on][gt]': 'csv',
            'filter[end_on][gte]': 'csv',
            'filter[end_on][lt]': 'csv',
            'filter[end_on][lte]': 'csv',
            'filter[person_id][eq]': 'csv',
            'filter[person_id][not_eq]': 'csv',
            'filter[person_id][gt]': 'csv',
            'filter[person_id][gte]': 'csv',
            'filter[person_id][lt]': 'csv',
            'filter[person_id][lte]': 'csv',
            'filter[group_id][eq]': 'csv',
            'filter[group_id][not_eq]': 'csv',
            'filter[group_id][gt]': 'csv',
            'filter[group_id][gte]': 'csv',
            'filter[group_id][lt]': 'csv',
            'filter[group_id][lte]': 'csv',
            'filter[type][eq]': 'csv',
            'filter[type][not_eq]': 'csv',
            'filter[type][eql]': 'csv',
            'filter[type][not_eql]': 'csv',
            'filter[type][prefix]': 'csv',
            'filter[type][not_prefix]': 'csv',
            'filter[type][suffix]': 'csv',
            'filter[type][not_suffix]': 'csv',
            'filter[type][match]': 'csv',
            'filter[type][not_match]': 'csv',
            'filter[label][eq]': 'csv',
            'filter[label][not_eq]': 'csv',
            'filter[label][eql]': 'csv',
            'filter[label][not_eql]': 'csv',
            'filter[label][prefix]': 'csv',
            'filter[label][not_prefix]': 'csv',
            'filter[label][suffix]': 'csv',
            'filter[label][not_suffix]': 'csv',
            'filter[label][match]': 'csv',
            'filter[label][not_match]': 'csv',
            'fields[people]': 'csv',
            'fields[groups]': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters

        if _additional_query_params is not None:
            _query_params.extend((key, value) for key, value in _additional_query_params.items())

        if include is not None:
            
            _query_params.append(('include', include))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if fields_roles is not None:
            
            _query_params.append(('fields[roles]', fields_roles))
            
        if filter_id_eq is not None:
            
            _query_params.append(('filter[id][eq]', filter_id_eq))
            
        if filter_id_not_eq is not None:
            
            _query_params.append(('filter[id][not_eq]', filter_id_not_eq))
            
        if filter_id_gt is not None:
            
            _query_params.append(('filter[id][gt]', filter_id_gt))
            
        if filter_id_gte is not None:
            
            _query_params.append(('filter[id][gte]', filter_id_gte))
            
        if filter_id_lt is not None:
            
            _query_params.append(('filter[id][lt]', filter_id_lt))
            
        if filter_id_lte is not None:
            
            _query_params.append(('filter[id][lte]', filter_id_lte))
            
        if filter_created_at_eq is not None:
            
            _query_params.append(('filter[created_at][eq]', filter_created_at_eq))
            
        if filter_created_at_not_eq is not None:
            
            _query_params.append(('filter[created_at][not_eq]', filter_created_at_not_eq))
            
        if filter_created_at_gt is not None:
            
            _query_params.append(('filter[created_at][gt]', filter_created_at_gt))
            
        if filter_created_at_gte is not None:
            
            _query_params.append(('filter[created_at][gte]', filter_created_at_gte))
            
        if filter_created_at_lt is not None:
            
            _query_params.append(('filter[created_at][lt]', filter_created_at_lt))
            
        if filter_created_at_lte is not None:
            
            _query_params.append(('filter[created_at][lte]', filter_created_at_lte))
            
        if filter_updated_at_eq is not None:
            
            _query_params.append(('filter[updated_at][eq]', filter_updated_at_eq))
            
        if filter_updated_at_not_eq is not None:
            
            _query_params.append(('filter[updated_at][not_eq]', filter_updated_at_not_eq))
            
        if filter_updated_at_gt is not None:
            
            _query_params.append(('filter[updated_at][gt]', filter_updated_at_gt))
            
        if filter_updated_at_gte is not None:
            
            _query_params.append(('filter[updated_at][gte]', filter_updated_at_gte))
            
        if filter_updated_at_lt is not None:
            
            _query_params.append(('filter[updated_at][lt]', filter_updated_at_lt))
            
        if filter_updated_at_lte is not None:
            
            _query_params.append(('filter[updated_at][lte]', filter_updated_at_lte))
            
        if filter_start_on_eq is not None:
            
            _query_params.append(('filter[start_on][eq]', filter_start_on_eq))
            
        if filter_start_on_not_eq is not None:
            
            _query_params.append(('filter[start_on][not_eq]', filter_start_on_not_eq))
            
        if filter_start_on_gt is not None:
            
            _query_params.append(('filter[start_on][gt]', filter_start_on_gt))
            
        if filter_start_on_gte is not None:
            
            _query_params.append(('filter[start_on][gte]', filter_start_on_gte))
            
        if filter_start_on_lt is not None:
            
            _query_params.append(('filter[start_on][lt]', filter_start_on_lt))
            
        if filter_start_on_lte is not None:
            
            _query_params.append(('filter[start_on][lte]', filter_start_on_lte))
            
        if filter_end_on_eq is not None:
            
            _query_params.append(('filter[end_on][eq]', filter_end_on_eq))
            
        if filter_end_on_not_eq is not None:
            
            _query_params.append(('filter[end_on][not_eq]', filter_end_on_not_eq))
            
        if filter_end_on_gt is not None:
            
            _query_params.append(('filter[end_on][gt]', filter_end_on_gt))
            
        if filter_end_on_gte is not None:
            
            _query_params.append(('filter[end_on][gte]', filter_end_on_gte))
            
        if filter_end_on_lt is not None:
            
            _query_params.append(('filter[end_on][lt]', filter_end_on_lt))
            
        if filter_end_on_lte is not None:
            
            _query_params.append(('filter[end_on][lte]', filter_end_on_lte))
            
        if filter_person_id_eq is not None:
            
            _query_params.append(('filter[person_id][eq]', filter_person_id_eq))
            
        if filter_person_id_not_eq is not None:
            
            _query_params.append(('filter[person_id][not_eq]', filter_person_id_not_eq))
            
        if filter_person_id_gt is not None:
            
            _query_params.append(('filter[person_id][gt]', filter_person_id_gt))
            
        if filter_person_id_gte is not None:
            
            _query_params.append(('filter[person_id][gte]', filter_person_id_gte))
            
        if filter_person_id_lt is not None:
            
            _query_params.append(('filter[person_id][lt]', filter_person_id_lt))
            
        if filter_person_id_lte is not None:
            
            _query_params.append(('filter[person_id][lte]', filter_person_id_lte))
            
        if filter_group_id_eq is not None:
            
            _query_params.append(('filter[group_id][eq]', filter_group_id_eq))
            
        if filter_group_id_not_eq is not None:
            
            _query_params.append(('filter[group_id][not_eq]', filter_group_id_not_eq))
            
        if filter_group_id_gt is not None:
            
            _query_params.append(('filter[group_id][gt]', filter_group_id_gt))
            
        if filter_group_id_gte is not None:
            
            _query_params.append(('filter[group_id][gte]', filter_group_id_gte))
            
        if filter_group_id_lt is not None:
            
            _query_params.append(('filter[group_id][lt]', filter_group_id_lt))
            
        if filter_group_id_lte is not None:
            
            _query_params.append(('filter[group_id][lte]', filter_group_id_lte))
            
        if filter_type_eq is not None:
            
            _query_params.append(('filter[type][eq]', filter_type_eq))
            
        if filter_type_not_eq is not None:
            
            _query_params.append(('filter[type][not_eq]', filter_type_not_eq))
            
        if filter_type_eql is not None:
            
            _query_params.append(('filter[type][eql]', filter_type_eql))
            
        if filter_type_not_eql is not None:
            
            _query_params.append(('filter[type][not_eql]', filter_type_not_eql))
            
        if filter_type_prefix is not None:
            
            _query_params.append(('filter[type][prefix]', filter_type_prefix))
            
        if filter_type_not_prefix is not None:
            
            _query_params.append(('filter[type][not_prefix]', filter_type_not_prefix))
            
        if filter_type_suffix is not None:
            
            _query_params.append(('filter[type][suffix]', filter_type_suffix))
            
        if filter_type_not_suffix is not None:
            
            _query_params.append(('filter[type][not_suffix]', filter_type_not_suffix))
            
        if filter_type_match is not None:
            
            _query_params.append(('filter[type][match]', filter_type_match))
            
        if filter_type_not_match is not None:
            
            _query_params.append(('filter[type][not_match]', filter_type_not_match))
            
        if filter_label_eq is not None:
            
            _query_params.append(('filter[label][eq]', filter_label_eq))
            
        if filter_label_not_eq is not None:
            
            _query_params.append(('filter[label][not_eq]', filter_label_not_eq))
            
        if filter_label_eql is not None:
            
            _query_params.append(('filter[label][eql]', filter_label_eql))
            
        if filter_label_not_eql is not None:
            
            _query_params.append(('filter[label][not_eql]', filter_label_not_eql))
            
        if filter_label_prefix is not None:
            
            _query_params.append(('filter[label][prefix]', filter_label_prefix))
            
        if filter_label_not_prefix is not None:
            
            _query_params.append(('filter[label][not_prefix]', filter_label_not_prefix))
            
        if filter_label_suffix is not None:
            
            _query_params.append(('filter[label][suffix]', filter_label_suffix))
            
        if filter_label_not_suffix is not None:
            
            _query_params.append(('filter[label][not_suffix]', filter_label_not_suffix))
            
        if filter_label_match is not None:
            
            _query_params.append(('filter[label][match]', filter_label_match))
            
        if filter_label_not_match is not None:
            
            _query_params.append(('filter[label][not_match]', filter_label_not_match))
            
        if fields_people is not None:
            
            _query_params.append(('fields[people]', fields_people))
            
        if fields_groups is not None:
            
            _query_params.append(('fields[groups]', fields_groups))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if roles_request is not None:
            _body_params = roles_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/vnd.api+json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/vnd.api+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ServiceTokenAuthHeader', 
            'ServiceTokenAuthParam'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/roles/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


